@@ -4,7 +4,7 @@ use 5.008_001;
 use strict;
 use warnings;
 
-our $VERSION = '2.1.0';
+our $VERSION = '2.0001';
 
 use Carp              ();
 use File::Spec        ();
@@ -153,7 +153,6 @@ sub options { # overridable
         verbose      => 1,
         warn_handler => undef,
         die_handler  => undef,
-        pre_process_handler => undef,
 
         %{ $self->parser_option },
         %{ $self->compiler_option },
@@ -375,14 +374,10 @@ sub load_file {
 sub slurp_template {
     my($self, $input_layer, $fullpath) = @_;
 
-    if (ref $fullpath eq 'SCALAR') {
-        return $$fullpath;
-    } else {
-        open my($source), '<' . $input_layer, $fullpath
-            or $self->_error("LoadError: Cannot open $fullpath for reading: $!");
-        local $/;
-        return scalar <$source>;
-    }
+    open my($source), '<' . $input_layer, $fullpath
+        or $self->_error("LoadError: Cannot open $fullpath for reading: $!");
+    local $/;
+    return scalar <$source>;
 }
 
 sub _load_source {
@@ -400,7 +395,6 @@ sub _load_source {
     }
 
     my $source = $self->slurp_template($self->input_layer, $fullpath);
-    $source = $self->{pre_process_handler}->($source) if $self->{pre_process_handler};
     $self->{source}{$fi->{name}} = $source if _SAVE_SRC;
 
     my $asm = $self->compile($source,
@@ -526,10 +520,6 @@ sub _load_compiled {
                 return undef; # purge the cache
             }
         }
-        elsif($c->[0] eq 'literal') {
-            # force upgrade to avoid UTF-8 key issues
-            utf8::upgrade($c->[1]);
-        }
         push @asm, $c;
     }
 
@@ -665,7 +655,7 @@ Text::Xslate - Scalable template engine for Perl5
 
 =head1 VERSION
 
-This document describes Text::Xslate version 2.1.0.
+This document describes Text::Xslate version 2.0001.
 
 =head1 SYNOPSIS
 
@@ -688,7 +678,7 @@ This document describes Text::Xslate version 2.1.0.
     # for files
     print $tx->render('hello.tx', \%vars);
 
-    # for strings (easy but slow)
+    # for strings
     my $template = q{
         <h1><: $title :></h1>
         <ul>
@@ -707,9 +697,8 @@ safe as an HTML generator, and with rich features.
 
 There are a lot of template engines in CPAN, for example Template-Toolkit,
 Text::MicroTemplate, HTML::Template, and so on, but all of them have
-some weak points: a full-featured template engine may be slow,
-while a fast template engine may be too simple to use. This is why Xslate is
-developed, which is the best template engine for web applications.
+demerits at some points. This is why Xslate is developed and now it is
+well-honed as the standard template engine for web applications.
 
 The concept of Xslate is strongly influenced by Text::MicroTemplate
 and Template-Toolkit 2, but the central philosophy of Xslate is different
@@ -727,9 +716,8 @@ compiled into intermediate code, and then executed by the virtual machine,
 which is highly optimized for rendering templates. Thus, Xslate is
 much faster than any other template engines.
 
-The template roundup project by Sam Graham shows Text::Xslate got
-amazingly high scores in I<instance_reuse> condition
-(i.e. for persistent applications).
+The template roundup project by Sam Graham shows Text::Xslate got very
+high scores in I<instance_reuse> condition (i.e. for persistent application).
 
 =over
 
@@ -743,19 +731,18 @@ L<http://illusori.co.uk/projects/Template-Roundup/201010/performance_vs_variant_
 
 =back
 
-There are also benchmarks in F<benchmark/> directory in the Xslate distribution.
+There are some benchmarks in F<benchmark/> directory in the Xslate distribution.
 
 =head3 Smart escaping for HTML metacharacters
 
-Xslate employs the B<smart escaping strategy>, where a template engine
-escapes all the HTML metacharacters in template expressionsi unless users
-mark values as B<raw>.
-That is, the output is unlikely to prone to XSS.
+All HTML metacharacters in template expressions which are interpolated into
+template texts by the engine are escaped automatically. This means that, by default,
+the output is not prone to XSS.
 
 =head3 Template cascading
 
-Xslate supports the B<template cascading>, which allows you to extend
-templates with block modifiers. It is like a traditional template inclusion,
+Xslate supports B<template cascading>, which allows you to extend
+templates with block modifiers. It is like traditional template inclusion,
 but is more powerful.
 
 This mechanism is also called as template inheritance.
@@ -769,9 +756,9 @@ engine and even add a new syntax via extending the parser.
 
 =head2 Methods
 
-=head3 B<< Text::Xslate->new(%options) >>
+=head3 B<< Text::Xslate->new(%options) :XslateEngine >>
 
-Creates a new Xslate template engine with options. You can reuse the instance
+Creates a new xslate template engine with options. You can reuse the instance
 for multiple call of C<render()>.
 
 Possible options are:
@@ -783,10 +770,6 @@ Possible options are:
 Specifies the include paths, which may be directory names or virtual paths,
 i.e. HASH references which contain C<< $file_name => $content >> pairs.
 
-Note that if you use taint mode (C<-T>), you have to give absolute paths
-to C<path> and C<cache_dir>. Otherwise you'll get errors because they
-depend on the current working directory which might not be secure.
-
 =item C<< cache => $level // 1 >>
 
 Sets the cache level.
@@ -953,24 +936,6 @@ Specify the callback I<&cb> which is called on warnings.
 
 Specify the callback I<&cb> which is called on fatal errors.
 
-=item C<< pre_process_handler => \&cb >>
-
-Specify the callback I<&cb> which is called after templates are loaded from the disk
-in order to pre-process template.
-
-For example:
-
-    # Remove withespace from templates
-    my $tx = Text::Xslate->new(
-        pre_process_handler => sub {
-            my $text = shift;
-            $text=~s/\s+//g;
-            return $text;
-        }
-    );
-
-The first argument is the template text string, which can be both B<text strings> and C<byte strings>.
-
 =back
 
 =head3 B<< $tx->render($file, \%vars) :Str >>
@@ -1211,7 +1176,7 @@ the same in internals:
 
 =item *
 
-A "too-safe" HTML escaping filter which escape all the symbolic characters
+An "too-safe" HTML escaping filter which escape all the symbolic characters
 
 =back
 
@@ -1325,7 +1290,7 @@ Thanks to ueda for the suggestions.
 
 =head1 AUTHOR
 
-Fuji, Goro (gfx) E<lt>gfuji@cpan.orgE<gt>.
+Fuji, Goro (gfx) E<lt>gfuji(at)cpan.orgE<gt>
 
 Makamaka Hannyaharamitu (makamaka) (Text::Xslate::PP)
 
@@ -1333,7 +1298,7 @@ Maki, Daisuke (lestrrat) (Text::Xslate::Runner)
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2010-2013, Fuji, Goro (gfx). All rights reserved.
+Copyright (c) 2010, Fuji, Goro (gfx). All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
