@@ -3,7 +3,7 @@ package Text::Xslate::PP;
 use 5.008_001;
 use strict;
 
-our $VERSION = '2.1.0';
+our $VERSION = '2.0001';
 
 BEGIN{
     $ENV{XSLATE} = ($ENV{XSLATE} || '') . '[pp]';
@@ -571,19 +571,8 @@ sub tx_execute {
     local $st->{sa};
     local $st->{sb};
     local $st->{output} = '';
-
-    local $st->{current_frame} = $st->{current_frame};
-
-    eval {
-        $st->{code}->[0]->{ exec_code }->( $st );
-    };
-
+    $st->{code}->[0]->{ exec_code }->( $st );
     @{$st->{frame}->[-1]} = Text::Xslate::PP::TXframe_START_LVAR - 1;
-
-    if ($@) {
-        my $e = $@;
-        die $e;
-    }
     return $st->{output};
 }
 
@@ -658,7 +647,7 @@ Text::Xslate::PP - Yet another Text::Xslate runtime in pure Perl
 
 =head1 VERSION
 
-This document describes Text::Xslate::PP version 2.1.0.
+This document describes Text::Xslate::PP version 2.0001.
 
 =head1 DESCRIPTION
 
